@@ -1229,15 +1229,15 @@ gcm_calib_reference_kind_to_localised_string (GcmCalibrateReferenceKind kind)
 	}
 	if (kind == GCM_CALIBRATE_REFERENCE_KIND_COLOR_CHECKER) {
 		/* TRANSLATORS: this is probably a brand name */
-		return _("Color Checker");
+		return _("ColorChecker");
 	}
 	if (kind == GCM_CALIBRATE_REFERENCE_KIND_COLOR_CHECKER_DC) {
 		/* TRANSLATORS: this is probably a brand name */
-		return _("Color Checker DC");
+		return _("ColorChecker DC");
 	}
 	if (kind == GCM_CALIBRATE_REFERENCE_KIND_COLOR_CHECKER_SG) {
 		/* TRANSLATORS: this is probably a brand name */
-		return _("Color Checker SG");
+		return _("ColorChecker SG");
 	}
 	if (kind == GCM_CALIBRATE_REFERENCE_KIND_HUTCHCOLOR) {
 		/* TRANSLATORS: this is probably a brand name */
@@ -1436,10 +1436,46 @@ gcm_calib_setup_page_display_kind (GcmCalibratePriv *priv)
 	/* TRANSLATORS: this is intro page text */
 	gcm_calib_add_page_para (content, _("Select the monitor type that is attached to your computer."));
 
-	widget = gtk_radio_button_new_with_label (NULL, _("LCD"));
+	widget = gtk_radio_button_new_with_label (NULL, _("LCD (CCFL backlight)"));
 	g_object_set_data (G_OBJECT (widget),
 			   "GcmCalib::display-kind",
-			   GUINT_TO_POINTER (GCM_CALIBRATE_DEVICE_KIND_LCD));
+			   GUINT_TO_POINTER (GCM_CALIBRATE_DEVICE_KIND_LCD_CCFL));
+	g_signal_connect (widget, "toggled",
+			  G_CALLBACK (gcm_calib_display_kind_toggled_cb), priv);
+	gtk_box_pack_start (GTK_BOX (content), widget, FALSE, FALSE, 0);
+
+	list = gtk_radio_button_get_group (GTK_RADIO_BUTTON (widget));
+	widget = gtk_radio_button_new_with_label (list, _("LCD (White LED backlight)"));
+	g_object_set_data (G_OBJECT (widget),
+			   "GcmCalib::display-kind",
+			   GUINT_TO_POINTER (GCM_CALIBRATE_DEVICE_KIND_LCD_LED_WHITE));
+	g_signal_connect (widget, "toggled",
+			  G_CALLBACK (gcm_calib_display_kind_toggled_cb), priv);
+	gtk_box_pack_start (GTK_BOX (content), widget, FALSE, FALSE, 0);
+
+	list = gtk_radio_button_get_group (GTK_RADIO_BUTTON (widget));
+	widget = gtk_radio_button_new_with_label (list, _("LCD (RGB LED backlight)"));
+	g_object_set_data (G_OBJECT (widget),
+			   "GcmCalib::display-kind",
+			   GUINT_TO_POINTER (GCM_CALIBRATE_DEVICE_KIND_LCD_LED_RGB));
+	g_signal_connect (widget, "toggled",
+			  G_CALLBACK (gcm_calib_display_kind_toggled_cb), priv);
+	gtk_box_pack_start (GTK_BOX (content), widget, FALSE, FALSE, 0);
+
+	list = gtk_radio_button_get_group (GTK_RADIO_BUTTON (widget));
+	widget = gtk_radio_button_new_with_label (list, _("LCD (Wide Gamut RGB LED backlight)"));
+	g_object_set_data (G_OBJECT (widget),
+			   "GcmCalib::display-kind",
+			   GUINT_TO_POINTER (GCM_CALIBRATE_DEVICE_KIND_LCD_LED_RGB_WIDE));
+	g_signal_connect (widget, "toggled",
+			  G_CALLBACK (gcm_calib_display_kind_toggled_cb), priv);
+	gtk_box_pack_start (GTK_BOX (content), widget, FALSE, FALSE, 0);
+
+	list = gtk_radio_button_get_group (GTK_RADIO_BUTTON (widget));
+	widget = gtk_radio_button_new_with_label (list, _("LCD (Wide Gamut CCFL backlight)"));
+	g_object_set_data (G_OBJECT (widget),
+			   "GcmCalib::display-kind",
+			   GUINT_TO_POINTER (GCM_CALIBRATE_DEVICE_KIND_LCD_CCFL_WIDE));
 	g_signal_connect (widget, "toggled",
 			  G_CALLBACK (gcm_calib_display_kind_toggled_cb), priv);
 	gtk_box_pack_start (GTK_BOX (content), widget, FALSE, FALSE, 0);
@@ -1691,7 +1727,7 @@ gcm_calib_setup_page_precision (GcmCalibratePriv *priv)
 	GString *labels[3];
 	guint i;
 	guint values_printer[] = { 6, 4, 2}; /* sheets */
-	guint values_display[] = { 30, 20, 10}; /* minutes */
+	guint values_display[] = { 60, 40, 20}; /* minutes */
 	GtkAssistant *assistant = GTK_ASSISTANT (priv->main_window);
 
 	/* TRANSLATORS: this is the page title */
@@ -1765,7 +1801,6 @@ gcm_calib_setup_page_precision (GcmCalibratePriv *priv)
 	g_signal_connect (widget, "toggled",
 			  G_CALLBACK (gcm_calib_precision_toggled_cb), priv);
 	gtk_box_pack_start (GTK_BOX (content), widget, FALSE, FALSE, 0);
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), TRUE);
 
 	list = gtk_radio_button_get_group (GTK_RADIO_BUTTON (widget));
 	widget = gtk_radio_button_new_with_label (list, labels[2]->str);
@@ -1775,6 +1810,7 @@ gcm_calib_setup_page_precision (GcmCalibratePriv *priv)
 	g_signal_connect (widget, "toggled",
 			  G_CALLBACK (gcm_calib_precision_toggled_cb), priv);
 	gtk_box_pack_start (GTK_BOX (content), widget, FALSE, FALSE, 0);
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), TRUE);
 
 	/* add to assistant */
 	gtk_assistant_append_page (assistant, vbox);
@@ -2036,13 +2072,7 @@ gcm_calib_add_pages (GcmCalibratePriv *priv)
 	gcm_calib_setup_page_precision (priv);
 
 	if (priv->device_kind == CD_DEVICE_KIND_DISPLAY) {
-		if (!priv->internal_lcd) {
-			gcm_calib_setup_page_display_kind (priv);
-		} else {
-			g_object_set (priv->calibrate,
-				      "display-kind", GCM_CALIBRATE_DEVICE_KIND_LCD,
-				      NULL);
-		}
+		gcm_calib_setup_page_display_kind (priv);
 		gcm_calib_setup_page_display_temp (priv);
 	} else if (priv->device_kind == CD_DEVICE_KIND_PRINTER) {
 		gcm_calib_setup_page_print_kind (priv);
